diff --git a/acinclude.m4 b/acinclude.m4
index 8abef81..d65eb13 100644
--- a/acinclude.m4
+++ b/acinclude.m4
@@ -661,7 +661,7 @@ AC_DEFUN([SETUP_WXWIDGETS],
 			CFLAGS=`echo $CFLAGS | sed -e "s/-O2/-O0/g"`
 			CXXFLAGS=`echo $CXXFLAGS | sed -e "s/-O2/-O0/g"`
 			
-			pgadmin3_LDADD=`${WX_CONFIG} ${WX_STATIC} --libs std,stc,ogl --unicode=yes --debug=yes --version=${WX_VERSION} 2> /dev/null`
+			pgadmin3_LDADD=`${WX_CONFIG} ${WX_STATIC} --libs std,stc,ogl,aui --unicode=yes --debug=yes --version=${WX_VERSION} 2> /dev/null`
 			pgsTest_LDADD=`${WX_CONFIG} ${WX_STATIC} --libs base,core,xml --unicode=yes --debug=yes --version=${WX_VERSION} 2> /dev/null`
 			pgScript_LDADD=`${WX_CONFIG} ${WX_STATIC} --libs base,core,xml --unicode=yes --debug=yes --version=${WX_VERSION} 2> /dev/null`
 		else
@@ -670,7 +670,7 @@ AC_DEFUN([SETUP_WXWIDGETS],
 			CFLAGS=`echo $CFLAGS | sed -e "s/-g //g"`
 			CXXFLAGS=`echo $CXXFLAGS | sed -e "s/-g //g"`
 		
-			pgadmin3_LDADD=`${WX_CONFIG} ${WX_STATIC} --libs std,stc,ogl --unicode=yes --debug=no --version=${WX_VERSION} 2> /dev/null`
+			pgadmin3_LDADD=`${WX_CONFIG} ${WX_STATIC} --libs std,stc,ogl,aui --unicode=yes --debug=no --version=${WX_VERSION} 2> /dev/null`
 			pgsTest_LDADD=`${WX_CONFIG} ${WX_STATIC} --libs base,core,xml --unicode=yes --debug=no --version=${WX_VERSION} 2> /dev/null`
 			pgScript_LDADD=`${WX_CONFIG} ${WX_STATIC} --libs base,core,xml --unicode=yes --debug=no --version=${WX_VERSION} 2> /dev/null`
 		fi
diff --git a/bootstrap b/bootstrap
old mode 100644
new mode 100755
diff --git a/pgadmin/ctl/ctlAuiNotebook.cpp b/pgadmin/ctl/ctlAuiNotebook.cpp
index 796153e..04cfc1c 100644
--- a/pgadmin/ctl/ctlAuiNotebook.cpp
+++ b/pgadmin/ctl/ctlAuiNotebook.cpp
@@ -29,6 +29,13 @@ END_EVENT_TABLE()
 // Handle, and pass up child focus events
 void ctlAuiNotebook::OnChildFocus(wxChildFocusEvent &event)
 {
+	
+#if wxCHECK_VERSION(2, 9, 0)
+	wxAuiNotebook::OnChildFocusNotebook(event);
+	GetParent()->GetEventHandler()->AddPendingEvent(event);
+#else
 	wxAuiNotebook::OnChildFocus(event);
 	GetParent()->AddPendingEvent(event);
+#endif
+
 }
diff --git a/pgadmin/frm/frmQuery.cpp b/pgadmin/frm/frmQuery.cpp
index acb55a8..3a9ae68 100644
--- a/pgadmin/frm/frmQuery.cpp
+++ b/pgadmin/frm/frmQuery.cpp
@@ -417,7 +417,7 @@ frmQuery::frmQuery(frmMain *form, const wxString &_title, pgConn *_conn, const w
 	// Add the database selection bar
 	cbConnection = new wxBitmapComboBox(this, CTRLID_CONNECTION, wxEmptyString, wxDefaultPosition, wxSize(-1, -1), wxArrayString(), wxCB_READONLY | wxCB_DROPDOWN);
 	cbConnection->Append(conn->GetName(), CreateBitmap(GetServerColour(conn)), (void *)conn);
-	cbConnection->Append(_("<new connection>"), wxNullBitmap, (void *)0);
+	cbConnection->Append(_("<new connection>"), wxNullBitmap, (void *) NULL);
 
 	//Create SQL editor notebook
 	sqlNotebook = new ctlAuiNotebook(this, CTL_NTBKCENTER, wxDefaultPosition, wxDefaultSize, wxAUI_NB_TOP | wxAUI_NB_TAB_SPLIT | wxAUI_NB_TAB_MOVE | wxAUI_NB_SCROLL_BUTTONS | wxAUI_NB_WINDOWLIST_BUTTON);
diff --git a/pgadmin/gqb/gqbController.cpp b/pgadmin/gqb/gqbController.cpp
index a8dc614..d18a38f 100644
--- a/pgadmin/gqb/gqbController.cpp
+++ b/pgadmin/gqb/gqbController.cpp
@@ -586,16 +586,21 @@ BEGIN_EVENT_TABLE(gqbSplitter, wxSplitterWindow)
 END_EVENT_TABLE()
 
 gqbSplitter::gqbSplitter(wxWindow *parent, wxWindowID id, const wxPoint &point, const wxSize &size, long style)
-	: wxSplitterWindow(parent, id, point, size, style)
+	: wxSplitterWindow(parent, id, point, size, style),
+		tablesBrowser(NULL),
+		browserPanel(NULL)
 {
 }
 
 
 void gqbSplitter::onVerticalSashResize(wxSplitterEvent &event)
 {
-	wxSize s = tablesBrowser->GetSize();
-	s.SetWidth(event.GetSashPosition());
-	browserPanel->SetSize(s);
-	tablesBrowser->SetSize(s);
-	// GQB-TODO: Set a minimun value
+	if(tablesBrowser != NULL && browserPanel != NULL)
+	{
+		wxSize s = tablesBrowser->GetSize();
+		s.SetWidth(event.GetSashPosition());
+		browserPanel->SetSize(s);
+		tablesBrowser->SetSize(s);
+		// GQB-TODO: Set a minimun value
+	}
 }
diff --git a/pgadmin/include/db/pgSet.h b/pgadmin/include/db/pgSet.h
index ab66506..b1f7a3e 100644
--- a/pgadmin/include/db/pgSet.h
+++ b/pgadmin/include/db/pgSet.h
@@ -139,7 +139,7 @@ protected:
 	wxString ExecuteScalar(const wxString &sql) const;
 	wxMBConv &conv;
 	bool needColQuoting;
-	wxArrayString colTypes, colFullTypes;
+	mutable wxArrayString colTypes, colFullTypes;
 	wxArrayInt colClasses;
 };
 
diff --git a/pgadmin/include/utils/sysSettings.h b/pgadmin/include/utils/sysSettings.h
index 4454bff..8c09a5c 100644
--- a/pgadmin/include/utils/sysSettings.h
+++ b/pgadmin/include/utils/sysSettings.h
@@ -682,7 +682,7 @@ public:
 	{
 		return wxConfig::Write(key, value);
 	}
-	bool Write(const wxString &key, bool value);
+	
 	bool Write(const wxString &key, const wxPoint &value);
 	bool Write(const wxString &key, const wxSize &value);
 	bool Write(const wxString &key, const wxSize &size, const wxPoint &point)
@@ -691,6 +691,7 @@ public:
 		Write(key, size);
 		return true;
 	}
+	bool WriteBool(const wxString &key, bool value);
 
 	// Functions for reading settings
 	bool Read(const wxString &key, wxString *str, const wxString &defaultVal) const;
diff --git a/pgadmin/ui/dlgAddFavourite.xrc b/pgadmin/ui/dlgAddFavourite.xrc
index 927c7e8..26c1252 100644
--- a/pgadmin/ui/dlgAddFavourite.xrc
+++ b/pgadmin/ui/dlgAddFavourite.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgAddFavourite">
     <title>Add favourite</title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <minsize>216,225d</minsize>
       <cols>1</cols>
diff --git a/pgadmin/ui/dlgAggregate.xrc b/pgadmin/ui/dlgAggregate.xrc
index 3797d39..ed4d3bf 100644
--- a/pgadmin/ui/dlgAggregate.xrc
+++ b/pgadmin/ui/dlgAggregate.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgAggregate">
     <title></title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgCast.xrc b/pgadmin/ui/dlgCast.xrc
index 53783fd..276d29d 100644
--- a/pgadmin/ui/dlgCast.xrc
+++ b/pgadmin/ui/dlgCast.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgCast">
     <title></title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgCheck.xrc b/pgadmin/ui/dlgCheck.xrc
index c8b8bfd..043a51b 100644
--- a/pgadmin/ui/dlgCheck.xrc
+++ b/pgadmin/ui/dlgCheck.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgCheck">
     <title></title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgColumn.xrc b/pgadmin/ui/dlgColumn.xrc
index a92c960..3ff9f6a 100644
--- a/pgadmin/ui/dlgColumn.xrc
+++ b/pgadmin/ui/dlgColumn.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgColumn">
     <title></title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgConnect.xrc b/pgadmin/ui/dlgConnect.xrc
index efd5896..b80ee2f 100644
--- a/pgadmin/ui/dlgConnect.xrc
+++ b/pgadmin/ui/dlgConnect.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgConnect">
     <title>Connect to Server</title>
     <size>205,83d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxDIALOG_MODAL|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxDIALOG_MODAL|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <rows>5</rows>
diff --git a/pgadmin/ui/dlgConversion.xrc b/pgadmin/ui/dlgConversion.xrc
index 8d634e1..683d2f5 100644
--- a/pgadmin/ui/dlgConversion.xrc
+++ b/pgadmin/ui/dlgConversion.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgConversion">
     <title></title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgDatabase.xrc b/pgadmin/ui/dlgDatabase.xrc
index 8e3c982..540f813 100644
--- a/pgadmin/ui/dlgDatabase.xrc
+++ b/pgadmin/ui/dlgDatabase.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgDatabase">
     <title></title>
     <size>220,280d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
@@ -17,7 +17,6 @@
             <object class="wxPanel" name="pnlProperties">
               <object class="wxFlexGridSizer">
                 <cols>2</cols>
-                <rows>11</rows>
                 <vgap>5</vgap>
                 <hgap>5</hgap>
                 <growablerows>11</growablerows>
@@ -241,7 +240,6 @@
                 <object class="sizeritem">
                   <object class="wxFlexGridSizer">
                     <cols>2</cols>
-                    <rows>2</rows>
                     <vgap>5</vgap>
                     <hgap>5</hgap>
                     <growablecols>1</growablecols>
diff --git a/pgadmin/ui/dlgDirectDbg.xrc b/pgadmin/ui/dlgDirectDbg.xrc
index 1f2e114..9ae6f8c 100644
--- a/pgadmin/ui/dlgDirectDbg.xrc
+++ b/pgadmin/ui/dlgDirectDbg.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgDirectDbg">
     <title>View Data Options</title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgDomain.xrc b/pgadmin/ui/dlgDomain.xrc
index 9604726..af98acc 100644
--- a/pgadmin/ui/dlgDomain.xrc
+++ b/pgadmin/ui/dlgDomain.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgDomain">
     <title></title>
     <size>220,280d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgEditGridOptions.xrc b/pgadmin/ui/dlgEditGridOptions.xrc
index c54a3f8..c468add 100644
--- a/pgadmin/ui/dlgEditGridOptions.xrc
+++ b/pgadmin/ui/dlgEditGridOptions.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgEditGridOptions">
     <title>View Data Options</title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
@@ -156,4 +156,4 @@
       </object>
     </object>
   </object>
-</resource>
\ No newline at end of file
+</resource>
diff --git a/pgadmin/ui/dlgExtTable.xrc b/pgadmin/ui/dlgExtTable.xrc
index 24c0561..4a6571d 100644
--- a/pgadmin/ui/dlgExtTable.xrc
+++ b/pgadmin/ui/dlgExtTable.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgExtTable">
     <title></title>
     <size>218,260d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgFindReplace.xrc b/pgadmin/ui/dlgFindReplace.xrc
index 50898a0..84edb5e 100644
--- a/pgadmin/ui/dlgFindReplace.xrc
+++ b/pgadmin/ui/dlgFindReplace.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgFindReplace">
     <title>Find and Replace</title>
     <size>300,166d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <rows>3</rows>
diff --git a/pgadmin/ui/dlgForeignKey.xrc b/pgadmin/ui/dlgForeignKey.xrc
index 9ef1973..5814f7a 100644
--- a/pgadmin/ui/dlgForeignKey.xrc
+++ b/pgadmin/ui/dlgForeignKey.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgForeignKey">
     <title></title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
@@ -321,4 +321,4 @@
       </object>
     </object>
   </object>
-</resource>
\ No newline at end of file
+</resource>
diff --git a/pgadmin/ui/dlgFunction.xrc b/pgadmin/ui/dlgFunction.xrc
index 05f54ef..1299f08 100644
--- a/pgadmin/ui/dlgFunction.xrc
+++ b/pgadmin/ui/dlgFunction.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgFunction">
     <title></title>
     <size>300,280d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablecols>0</growablecols>
@@ -587,4 +587,4 @@
       </object>
     </object>
   </object>
-</resource>
\ No newline at end of file
+</resource>
diff --git a/pgadmin/ui/dlgGroup.xrc b/pgadmin/ui/dlgGroup.xrc
index 26f0bf4..f80b3d2 100644
--- a/pgadmin/ui/dlgGroup.xrc
+++ b/pgadmin/ui/dlgGroup.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgGroup">
     <title></title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgHbaConfig.xrc b/pgadmin/ui/dlgHbaConfig.xrc
index ee31e14..4a285ec 100644
--- a/pgadmin/ui/dlgHbaConfig.xrc
+++ b/pgadmin/ui/dlgHbaConfig.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgHbaConfig">
     <title>Client Access Configuration</title>
     <size>220,150d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <rows>2</rows>
diff --git a/pgadmin/ui/dlgIndex.xrc b/pgadmin/ui/dlgIndex.xrc
index 0c3f51f..0a05852 100644
--- a/pgadmin/ui/dlgIndex.xrc
+++ b/pgadmin/ui/dlgIndex.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgIndex">
     <title></title>
     <size>220,280d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
@@ -183,7 +183,6 @@
                 <object class="sizeritem">
                   <object class="wxFlexGridSizer">
                     <cols>2</cols>
-                    <rows>2</rows>
                     <vgap>5</vgap>
                     <hgap>5</hgap>
                     <growablecols>1</growablecols>
diff --git a/pgadmin/ui/dlgIndexConstraint.xrc b/pgadmin/ui/dlgIndexConstraint.xrc
index cb983dc..5298953 100644
--- a/pgadmin/ui/dlgIndexConstraint.xrc
+++ b/pgadmin/ui/dlgIndexConstraint.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgIndexConstraint">
     <title></title>
     <size>220,280d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
@@ -169,7 +169,6 @@
                 <object class="sizeritem">
                   <object class="wxFlexGridSizer">
                     <cols>2</cols>
-                    <rows>2</rows>
                     <vgap>5</vgap>
                     <hgap>5</hgap>
                     <growablecols>1</growablecols>
diff --git a/pgadmin/ui/dlgJob.xrc b/pgadmin/ui/dlgJob.xrc
index c7e0f13..e1563df 100644
--- a/pgadmin/ui/dlgJob.xrc
+++ b/pgadmin/ui/dlgJob.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgJob">
     <title></title>
     <size>220,280d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgLanguage.xrc b/pgadmin/ui/dlgLanguage.xrc
index 8fc531b..ce1eda9 100644
--- a/pgadmin/ui/dlgLanguage.xrc
+++ b/pgadmin/ui/dlgLanguage.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgLanguage">
     <title></title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgMainConfig.xrc b/pgadmin/ui/dlgMainConfig.xrc
index 1c6fa0b..0a41c7b 100644
--- a/pgadmin/ui/dlgMainConfig.xrc
+++ b/pgadmin/ui/dlgMainConfig.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgMainConfig">
     <title></title>
     <size>248,198d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <rows>4</rows>
diff --git a/pgadmin/ui/dlgManageFavourites.xrc b/pgadmin/ui/dlgManageFavourites.xrc
index 4f31a7d..04aea62 100644
--- a/pgadmin/ui/dlgManageFavourites.xrc
+++ b/pgadmin/ui/dlgManageFavourites.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgManageFavourites">
     <title>Manage favourites</title>
     <size>218,198d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <rows>3</rows>
diff --git a/pgadmin/ui/dlgManageMacros.xrc b/pgadmin/ui/dlgManageMacros.xrc
index 0ed2376..4180bc4 100644
--- a/pgadmin/ui/dlgManageMacros.xrc
+++ b/pgadmin/ui/dlgManageMacros.xrc
@@ -2,7 +2,7 @@
 <resource>
   <object class="wxDialog" name="dlgManageMacros">
     <title>Manage Macros</title>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxTHICK_FRAME|wxRESIZE_BORDER|wxRESIZE_BOX</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <vgap>5</vgap>
diff --git a/pgadmin/ui/dlgOperator.xrc b/pgadmin/ui/dlgOperator.xrc
index a3120a4..3fb7c7b 100644
--- a/pgadmin/ui/dlgOperator.xrc
+++ b/pgadmin/ui/dlgOperator.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgOperator">
     <title></title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgPackage.xrc b/pgadmin/ui/dlgPackage.xrc
index 47d63df..417eabf 100644
--- a/pgadmin/ui/dlgPackage.xrc
+++ b/pgadmin/ui/dlgPackage.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgPackage">
     <title></title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgPgpassConfig.xrc b/pgadmin/ui/dlgPgpassConfig.xrc
index 59117eb..c5502f2 100644
--- a/pgadmin/ui/dlgPgpassConfig.xrc
+++ b/pgadmin/ui/dlgPgpassConfig.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgPgpassConfig">
     <title>Client Access Configuration</title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <rows>2</rows>
diff --git a/pgadmin/ui/dlgReassignDropOwned.xrc b/pgadmin/ui/dlgReassignDropOwned.xrc
index f99b908..1beb8e6 100644
--- a/pgadmin/ui/dlgReassignDropOwned.xrc
+++ b/pgadmin/ui/dlgReassignDropOwned.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgReassignDropOwned">
     <title>Reassign/Drop Owned</title>
     <size>200,200d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <rows>2</rows>
diff --git a/pgadmin/ui/dlgRepCluster.xrc b/pgadmin/ui/dlgRepCluster.xrc
index 1cc1cf2..71f58c4 100644
--- a/pgadmin/ui/dlgRepCluster.xrc
+++ b/pgadmin/ui/dlgRepCluster.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgRepCluster">
     <title></title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgRepClusterUpgrade.xrc b/pgadmin/ui/dlgRepClusterUpgrade.xrc
index dfbb50e..3ba9bee 100644
--- a/pgadmin/ui/dlgRepClusterUpgrade.xrc
+++ b/pgadmin/ui/dlgRepClusterUpgrade.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgRepClusterUpgrade">
     <title>Upgrade cluster software</title>
     <size>220,150d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgRepListen.xrc b/pgadmin/ui/dlgRepListen.xrc
index 6a5983b..2aab597 100644
--- a/pgadmin/ui/dlgRepListen.xrc
+++ b/pgadmin/ui/dlgRepListen.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgRepListen">
     <title></title>
     <size>220,150</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgRepNode.xrc b/pgadmin/ui/dlgRepNode.xrc
index bdbd3f9..5c8dda7 100644
--- a/pgadmin/ui/dlgRepNode.xrc
+++ b/pgadmin/ui/dlgRepNode.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgRepNode">
     <title></title>
     <size>220,150</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgRepPath.xrc b/pgadmin/ui/dlgRepPath.xrc
index d63135a..2f3f1bf 100644
--- a/pgadmin/ui/dlgRepPath.xrc
+++ b/pgadmin/ui/dlgRepPath.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgRepPath">
     <title></title>
     <size>220,150</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgRepSequence.xrc b/pgadmin/ui/dlgRepSequence.xrc
index 20f5419..c92e6f5 100644
--- a/pgadmin/ui/dlgRepSequence.xrc
+++ b/pgadmin/ui/dlgRepSequence.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgRepSequence">
     <title></title>
     <size>220,150</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgRepSet.xrc b/pgadmin/ui/dlgRepSet.xrc
index 4b9a253..965590f 100644
--- a/pgadmin/ui/dlgRepSet.xrc
+++ b/pgadmin/ui/dlgRepSet.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgRepSet">
     <title></title>
     <size>220,150d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgRepSetMerge.xrc b/pgadmin/ui/dlgRepSetMerge.xrc
index 991e41e..40c45f8 100644
--- a/pgadmin/ui/dlgRepSetMerge.xrc
+++ b/pgadmin/ui/dlgRepSetMerge.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgRepSetMerge">
     <title>Merge set into another set</title>
     <size>220,150d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgRepSetMove.xrc b/pgadmin/ui/dlgRepSetMove.xrc
index 081305e..8412711 100644
--- a/pgadmin/ui/dlgRepSetMove.xrc
+++ b/pgadmin/ui/dlgRepSetMove.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgRepSetMove">
     <title>Move set to other node</title>
     <size>220,150d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgRepSubscription.xrc b/pgadmin/ui/dlgRepSubscription.xrc
index 86ecd34..a5519d1 100644
--- a/pgadmin/ui/dlgRepSubscription.xrc
+++ b/pgadmin/ui/dlgRepSubscription.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgRepSubscription">
     <title></title>
     <size>220,150d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgRepTable.xrc b/pgadmin/ui/dlgRepTable.xrc
index 992f3c1..a49e31b 100644
--- a/pgadmin/ui/dlgRepTable.xrc
+++ b/pgadmin/ui/dlgRepTable.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgRepTable">
     <title></title>
     <size>220,150d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgRole.xrc b/pgadmin/ui/dlgRole.xrc
index 13e72c1..0d5287a 100644
--- a/pgadmin/ui/dlgRole.xrc
+++ b/pgadmin/ui/dlgRole.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgRole">
     <title></title>
     <size>300,280d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
@@ -172,7 +172,6 @@
             <object class="wxPanel" name="pnlRolesPriv">
               <object class="wxFlexGridSizer">
                 <cols>1</cols>
-                <rows>5</rows>
                 <vgap>5</vgap>
                 <hgap>5</hgap>
                 <growablecols>0</growablecols>
diff --git a/pgadmin/ui/dlgRule.xrc b/pgadmin/ui/dlgRule.xrc
index dc77c0f..4013907 100644
--- a/pgadmin/ui/dlgRule.xrc
+++ b/pgadmin/ui/dlgRule.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgRule">
     <title></title>
     <size>220,280d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgSchedule.xrc b/pgadmin/ui/dlgSchedule.xrc
index 4f90a90..e52b851 100644
--- a/pgadmin/ui/dlgSchedule.xrc
+++ b/pgadmin/ui/dlgSchedule.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgSchedule">
     <title></title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgSchema.xrc b/pgadmin/ui/dlgSchema.xrc
index 1565e7e..b431fe7 100644
--- a/pgadmin/ui/dlgSchema.xrc
+++ b/pgadmin/ui/dlgSchema.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgSchema">
     <title></title>
     <size>220,280d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgSequence.xrc b/pgadmin/ui/dlgSequence.xrc
index bb6cee4..b6ee14e 100644
--- a/pgadmin/ui/dlgSequence.xrc
+++ b/pgadmin/ui/dlgSequence.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgSequence">
     <title></title>
     <size>220,280d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgServer.xrc b/pgadmin/ui/dlgServer.xrc
index acbaba8..c8632f2 100644
--- a/pgadmin/ui/dlgServer.xrc
+++ b/pgadmin/ui/dlgServer.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgServer">
     <title></title>
     <size>220,240d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgStep.xrc b/pgadmin/ui/dlgStep.xrc
index 1e6859c..d1d815f 100644
--- a/pgadmin/ui/dlgStep.xrc
+++ b/pgadmin/ui/dlgStep.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgStep">
     <title></title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgSynonym.xrc b/pgadmin/ui/dlgSynonym.xrc
index f10669f..4ebded9 100644
--- a/pgadmin/ui/dlgSynonym.xrc
+++ b/pgadmin/ui/dlgSynonym.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgSynonym">
     <title></title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgTable.xrc b/pgadmin/ui/dlgTable.xrc
index 0af2c99..01ecdbb 100644
--- a/pgadmin/ui/dlgTable.xrc
+++ b/pgadmin/ui/dlgTable.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgTable">
     <title></title>
     <size>300,280d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
@@ -329,7 +329,6 @@
                 <object class="wxPanel">
                   <object class="wxFlexGridSizer">
                     <cols>3</cols>
-                    <rows>11</rows>
                     <vgap>5</vgap>
                     <hgap>5</hgap>
                     <growablecols>1</growablecols>
@@ -555,7 +554,6 @@
                 <object class="wxPanel">
                   <object class="wxFlexGridSizer">
                     <cols>3</cols>
-                    <rows>11</rows>
                     <vgap>5</vgap>
                     <hgap>5</hgap>
                     <growablecols>1</growablecols>
diff --git a/pgadmin/ui/dlgTablespace.xrc b/pgadmin/ui/dlgTablespace.xrc
index ed544f9..26371c7 100644
--- a/pgadmin/ui/dlgTablespace.xrc
+++ b/pgadmin/ui/dlgTablespace.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgTablespace">
     <title></title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgTextSearchConfiguration.xrc b/pgadmin/ui/dlgTextSearchConfiguration.xrc
index a0f79b9..50f6b97 100644
--- a/pgadmin/ui/dlgTextSearchConfiguration.xrc
+++ b/pgadmin/ui/dlgTextSearchConfiguration.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgTextSearchConfiguration">
     <title></title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgTextSearchDictionary.xrc b/pgadmin/ui/dlgTextSearchDictionary.xrc
index d34bbb4..ed526ac 100644
--- a/pgadmin/ui/dlgTextSearchDictionary.xrc
+++ b/pgadmin/ui/dlgTextSearchDictionary.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgTextSearchDictionary">
     <title></title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablecols>0</growablecols>
diff --git a/pgadmin/ui/dlgTextSearchParser.xrc b/pgadmin/ui/dlgTextSearchParser.xrc
index 1e7e300..21ac081 100644
--- a/pgadmin/ui/dlgTextSearchParser.xrc
+++ b/pgadmin/ui/dlgTextSearchParser.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgTextSearchParser">
     <title></title>
     <size>220,280d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablecols>0</growablecols>
diff --git a/pgadmin/ui/dlgTextSearchTemplate.xrc b/pgadmin/ui/dlgTextSearchTemplate.xrc
index 29812b3..52c2537 100644
--- a/pgadmin/ui/dlgTextSearchTemplate.xrc
+++ b/pgadmin/ui/dlgTextSearchTemplate.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgTextSearchTemplate">
     <title></title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablecols>0</growablecols>
diff --git a/pgadmin/ui/dlgTrigger.xrc b/pgadmin/ui/dlgTrigger.xrc
index 091803c..c6ac6c0 100644
--- a/pgadmin/ui/dlgTrigger.xrc
+++ b/pgadmin/ui/dlgTrigger.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgTrigger">
     <title></title>
     <size>220,280d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgType.xrc b/pgadmin/ui/dlgType.xrc
index c33155f..d362054 100644
--- a/pgadmin/ui/dlgType.xrc
+++ b/pgadmin/ui/dlgType.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgType">
     <title></title>
     <size>220,280d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgUser.xrc b/pgadmin/ui/dlgUser.xrc
index d27fed2..998979b 100644
--- a/pgadmin/ui/dlgUser.xrc
+++ b/pgadmin/ui/dlgUser.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgUser">
     <title></title>
     <size>220,250d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/dlgView.xrc b/pgadmin/ui/dlgView.xrc
index 6d92200..0e9f78f 100644
--- a/pgadmin/ui/dlgView.xrc
+++ b/pgadmin/ui/dlgView.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="dlgView">
     <title></title>
     <size>220,280d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
diff --git a/pgadmin/ui/frmBackup.xrc b/pgadmin/ui/frmBackup.xrc
index 5a89a92..5881410 100644
--- a/pgadmin/ui/frmBackup.xrc
+++ b/pgadmin/ui/frmBackup.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="frmBackup">
     <title>Backup</title>
     <size>300,233d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <rows>2</rows>
diff --git a/pgadmin/ui/frmBackupGlobals.xrc b/pgadmin/ui/frmBackupGlobals.xrc
index eabb678..ba5a1e1 100644
--- a/pgadmin/ui/frmBackupGlobals.xrc
+++ b/pgadmin/ui/frmBackupGlobals.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="frmBackupGlobals">
     <title>Backup Globals</title>
     <size>210,153d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <rows>3</rows>
diff --git a/pgadmin/ui/frmBackupServer.xrc b/pgadmin/ui/frmBackupServer.xrc
index 9ea72b6..33a1294 100644
--- a/pgadmin/ui/frmBackupServer.xrc
+++ b/pgadmin/ui/frmBackupServer.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="frmBackupServer">
     <title>Backup Server</title>
     <size>210,153d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <rows>3</rows>
diff --git a/pgadmin/ui/frmHint.xrc b/pgadmin/ui/frmHint.xrc
index 35eaa1c..5b575bc 100644
--- a/pgadmin/ui/frmHint.xrc
+++ b/pgadmin/ui/frmHint.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="frmHint">
     <title>pgAdmin Guru Hint</title>
     <size>200,153d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <rows>3</rows>
@@ -89,4 +89,4 @@
       <growablerows>0</growablerows>
     </object>
   </object>
-</resource>
\ No newline at end of file
+</resource>
diff --git a/pgadmin/ui/frmMaintenance.xrc b/pgadmin/ui/frmMaintenance.xrc
index 048ab00..436c0d4 100644
--- a/pgadmin/ui/frmMaintenance.xrc
+++ b/pgadmin/ui/frmMaintenance.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="frmMaintenance">
     <title>Maintenance</title>
     <size>200,153d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <rows>2</rows>
diff --git a/pgadmin/ui/frmOptions.xrc b/pgadmin/ui/frmOptions.xrc
index a412637..52f86ca 100644
--- a/pgadmin/ui/frmOptions.xrc
+++ b/pgadmin/ui/frmOptions.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="frmOptions">
     <title>Options</title>
     <size>350,350d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <growablerows>0</growablerows>
@@ -1031,4 +1031,4 @@
       </object>
     </object>
   </object>
-</resource>
\ No newline at end of file
+</resource>
diff --git a/pgadmin/ui/frmRestore.xrc b/pgadmin/ui/frmRestore.xrc
index 8e6ef2f..937f946 100644
--- a/pgadmin/ui/frmRestore.xrc
+++ b/pgadmin/ui/frmRestore.xrc
@@ -3,7 +3,7 @@
   <object class="wxDialog" name="frmRestore">
     <title>Restore</title>
     <size>300,193d</size>
-    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER|wxRESIZE_BOX|wxTHICK_FRAME</style>
+    <style>wxDEFAULT_DIALOG_STYLE|wxCAPTION|wxSYSTEM_MENU|wxRESIZE_BORDER</style>
     <object class="wxFlexGridSizer">
       <cols>1</cols>
       <rows>2</rows>
diff --git a/pgadmin/utils/sysLogger.cpp b/pgadmin/utils/sysLogger.cpp
index bfc07bc..3a26ca5 100644
--- a/pgadmin/utils/sysLogger.cpp
+++ b/pgadmin/utils/sysLogger.cpp
@@ -27,6 +27,8 @@
 wxLogLevel sysLogger::logLevel = LOG_ERRORS;
 wxString sysLogger::logFile = wxT("debug.log");
 
+#if !wxCHECK_VERSION(2, 9, 0)
+
 // IMPLEMENT_LOG_FUNCTION(Sql) from wx../common/log.c
 void wxVLogQuietError(const wxChar *szFormat, va_list argptr)
 {
@@ -128,6 +130,7 @@ void wxLogScriptVerbose(const wxChar *szFormat, ...)
 	va_end(argptr);
 }
 
+#endif
 
 void sysLogger::DoLog(wxLogLevel level, const wxChar *msg, time_t timestamp)
 {
diff --git a/pgadmin/utils/sysSettings.cpp b/pgadmin/utils/sysSettings.cpp
index 2c16387..b1d862c 100644
--- a/pgadmin/utils/sysSettings.cpp
+++ b/pgadmin/utils/sysSettings.cpp
@@ -370,12 +370,6 @@ wxSize sysSettings::Read(const wxString &key, const wxSize &defaultVal) const
 	              wxConfig::Read(key + wxT("/Height"), actualDefault.y));
 }
 
-// Write a boolean value
-bool sysSettings::Write(const wxString &key, bool value)
-{
-	return Write(key, BoolToStr(value));
-}
-
 // Write a point value
 bool sysSettings::Write(const wxString &key, const wxPoint &value)
 {
@@ -394,6 +388,12 @@ bool sysSettings::Write(const wxString &key, const wxSize &value)
 	return rc;
 }
 
+// Write a boolean value
+bool sysSettings::WriteBool(const wxString &key, bool value)
+{
+	return Write(key, BoolToStr(value));
+}
+
 //////////////////////////////////////////////////////////////////////////
 // Log
 //////////////////////////////////////////////////////////////////////////
